==> lori_sdk-0.1.10.tar.gz: lib/data/database/web/webSearchTermsDao.dart <==
import 'package:lori_sdk/data/database/interfaces/searchTermsDao.dart';
import 'package:lori_sdk/data/models/singleton/searchTermsSingleton.dart';
import 'package:shared_preferences/shared_preferences.dart';

class WebSearchedTermsDao implements SearchTermsDao {
  static const SEARCHED_TERMS = 'key_searched_terms';

  static const SEARCH_HISTORY_MAX_SIZE = 5;

  Future<void> insertOrUpdate(String term) async {
    //Initialize the array if empty
    var searchedTerms = await get() ?? List<String>();

    //Delete the item from the array if already present
    if (searchedTerms.contains(term)) {
      searchedTerms.remove(term);
    }

    //Add the item to the end of the array
    searchedTerms.add(term);

    var updatedTerms = await _updateList(searchedTerms);

    return SearchedTermsSingleton().searchTermsChanged(updatedTerms);
  }

  //Internal method to update the internal list at once
  //Since we are not using a database here we always have to save the entire list
  Future<List<String>> _updateList(List<String> searchedTerms) async {
    var preferences = await SharedPreferences.getInstance();
    //Since we have a max length for the history there is no reason to save more terms
    //  than the amount that will be shown
    var searchedTermsToSave = searchedTerms.reversed
        .take(SEARCH_HISTORY_MAX_SIZE)
        .toList()
        .reversed
        .toList();
    await preferences.setStringList(SEARCHED_TERMS, searchedTermsToSave);
    return searchedTerms;
  }

  Future<List<String>> get() async {
    var preferences = await SharedPreferences.getInstance();
    if (preferences.getKeys().contains(SEARCHED_TERMS)) {
      return preferences.getStringList(SEARCHED_TERMS);
    } else {
      return null;
    }
  }

  Future<void> delete(String term) async {
    var searchedTerms = await get();
    searchedTerms.remove(term);
    var updatedTerms = await _updateList(searchedTerms);

    return SearchedTermsSingleton().searchTermsChanged(updatedTerms);
  }
}

SearchTermsDao getSearchTermsDao() => WebSearchedTermsDao();

==> lori_sdk-0.9.2.tar.gz: lib/data/database/web/webSearchTermsDao.dart <==
import 'package:lori_sdk/data/database/interfaces/searchTermsDao.dart';
import 'package:lori_sdk/data/models/singleton/searchTermsSingleton.dart';
import 'package:shared_preferences/shared_preferences.dart';

class WebSearchedTermsDao implements SearchTermsDao {
  static const SEARCHED_TERMS = 'key_searched_terms';

  static const SEARCH_HISTORY_MAX_SIZE = 5;

  Future<void> insertOrUpdate(String term) async {
    //Initialize the array if empty
    var searchedTerms = await get() ?? <String>[];

    //Delete the item from the array if already present
    if (searchedTerms.contains(term)) {
      searchedTerms.remove(term);
    }

    //Add the item to the end of the array
    searchedTerms.add(term);

    var updatedTerms = await _updateList(searchedTerms);

    return SearchedTermsSingleton().searchTermsChanged(updatedTerms);
  }

  //Internal method to update the internal list at once
  //Since we are not using a database here we always have to save the entire list
  Future<List<String>> _updateList(List<String> searchedTerms) async {
    var preferences = await SharedPreferences.getInstance();
    //Since we have a max length for the history there is no reason to save more terms
    //  than the amount that will be shown
    var searchedTermsToSave = searchedTerms.reversed.take(SEARCH_HISTORY_MAX_SIZE).toList().reversed.toList();
    await preferences.setStringList(SEARCHED_TERMS, searchedTermsToSave);
    return searchedTerms;
  }

  Future<List<String>> get() async {
    var preferences = await SharedPreferences.getInstance();
    if (preferences.getKeys().contains(SEARCHED_TERMS)) {
      return preferences.getStringList(SEARCHED_TERMS);
    } else {
      return null;
    }
  }

  Future<void> delete(String term) async {
    var searchedTerms = await get();
    searchedTerms.remove(term);
    var updatedTerms = await _updateList(searchedTerms);

    return SearchedTermsSingleton().searchTermsChanged(updatedTerms);
  }
}

SearchTermsDao getSearchTermsDao() => WebSearchedTermsDao();
